@@ -1,7 +1,9 @@
+import math
 import os
 import sqlite3
 import sys
 import warnings
+from enum import Enum
 from itertools import count, repeat
 from typing import Any, Optional, Tuple, Union, cast, overload
 
@@ -84,6 +86,12 @@ def _strict_zip(iter1: Iterable[Any], iter2: Iterable[Any]) -> Iterable[Tuple[An
             raise DifferentLengthDetected(element_count + iter1_unused_count, element_count + iter2_unused_count)
 
 
+class SortingStrategy(str, Enum):
+    fastest = "fastest"
+    balanced = "balanced"
+    memory_saving = "memory_saving"
+
+
 class _ListDatabaseDriver(_SqliteCollectionBaseDatabaseDriver):
     if sys.version_info >= (3, 9):
 
@@ -178,9 +186,9 @@ class _ListDatabaseDriver(_SqliteCollectionBaseDatabaseDriver):
     def remap_index(cls, table_name: str, cur: sqlite3.Cursor, indices_map: Iterable[int]) -> None:
         l = cls.get_max_index_plus_one(table_name, cur)
         cur.execute(f"UPDATE {table_name} SET item_index = item_index - ?", (l,))
-        cur.execute(
-            f"UPDATE {table_name} SET item_index = CASE item_index {' '.join(['WHEN ? THEN ?' for _ in range(l)])} END",
-            sum(((j - l, i) for i, j in enumerate(indices_map)), tuple()),
+        cur.executemany(
+            f"UPDATE {table_name} SET item_index = ? WHERE item_index = ?",
+            ((i, j - l) for i, j in enumerate(indices_map)),
         )
 
     @classmethod
@@ -251,6 +259,23 @@ class _ListDatabaseDriver(_SqliteCollectionBaseDatabaseDriver):
         for d in serialized_records:
             cur.execute(f"INSERT INTO {table_name} (serialized_value, item_index) VALUES (?, ?)", d)
 
+    @classmethod
+    def swap_indices(cls, table_name: str, cur: sqlite3.Cursor, idx1: int, idx2: int) -> None:
+        cur.execute(f"UPDATE {table_name} SET item_index = -1 WHERE item_index = ?", (idx1,))
+        cur.execute(f"UPDATE {table_name} SET item_index = ? WHERE item_index = ?", (idx1, idx2))
+        cur.execute(f"UPDATE {table_name} SET item_index = ? WHERE item_index = -1", (idx2,))
+
+    @classmethod
+    def increase_indices_in_range(cls, table_name: str, cur: sqlite3.Cursor, start: int, end: int, value: int) -> None:
+        cur.execute(
+            f"UPDATE {table_name} SET item_index = item_index + ? WHERE item_index >= ? AND item_index < ?",
+            (value, start, end),
+        )
+
+    @classmethod
+    def set_index_by_index(cls, table_name: str, cur: sqlite3.Cursor, old_index: int, new_index: int) -> None:
+        cur.execute(f"UPDATE {table_name} SET item_index = ? WHERE item_index = ?", (new_index, old_index))
+
 
 class List(SqliteCollectionBase[T], MutableSequence[T]):
     _driver_class = _ListDatabaseDriver
@@ -264,6 +289,7 @@ class List(SqliteCollectionBase[T], MutableSequence[T]):
         deserializer: Optional[Callable[[bytes], T]] = None,
         persist: bool = True,
         pickling_strategy: PicklingStrategy = PicklingStrategy.whole_table,
+        sorting_strategy: SortingStrategy = SortingStrategy.balanced,
     ) -> None:
         if (
             isinstance(__data, self.__class__)
@@ -292,6 +318,13 @@ class List(SqliteCollectionBase[T], MutableSequence[T]):
             if __data is not None:
                 self.clear()
                 self.extend(__data)
+        self._sorting_strategy = sorting_strategy
+
+    @property
+    def sorting_strategy(self) -> SortingStrategy:
+        if hasattr(self, "_sorting_strategy"):
+            return self._sorting_strategy
+        return SortingStrategy.balanced
 
     def __delitem__(self, i: Union[int, slice]) -> None:
         cur = self.connection.cursor()
@@ -504,15 +537,109 @@ class List(SqliteCollectionBase[T], MutableSequence[T]):
 
     def sort(self, reverse: bool = False, key: Optional[Callable[[T], Any]] = None) -> None:
         key_ = (lambda x: x) if key is None else key
-        cur = self.connection.cursor()
-        buf = [
-            (key_(self.deserialize(v)), i)
-            for i, v in enumerate(self._driver_class.iter_serialized_value(self.table_name, cur))
-        ]
-        buf.sort(key=lambda x: x[0], reverse=reverse)  # type: ignore
-        self._driver_class.remap_index(self.table_name, cur, [i[1] for i in buf])
+        if self.sorting_strategy == SortingStrategy.fastest:
+            self._sort_cached_keys(reverse=reverse, key=key_)
+        elif self.sorting_strategy == SortingStrategy.memory_saving:
+            self._merge_sort(reverse, key_, 0, len(self))
+        else:
+            self._sort_indices(reverse=reverse, key=key_)
         self.connection.commit()
 
+    def _sort_indices(self, reverse: bool, key: Callable[[T], Any]) -> None:
+        indices = list(range(len(self)))
+        indices.sort(key=lambda i: key(self[i]), reverse=reverse)  # type: ignore
+        self._driver_class.remap_index(self.table_name, self.connection.cursor(), indices)
+
+    def _sort_cached_keys(self, reverse: bool, key: Callable[[T], Any]) -> None:
+        key_cache = [(key(v), i) for i, v in enumerate(self)]
+        key_cache.sort(key=lambda t: t[0], reverse=reverse)  # type: ignore
+        self._driver_class.remap_index(self.table_name, self.connection.cursor(), [t[1] for t in key_cache])
+
+    def _merge_sort(self, reverse: bool, key: Callable[[T], Any], idx0: int, idx1: int) -> None:
+        sz = idx1 - idx0
+        if sz <= 3:
+            if sz == 3:
+                self.__sort3(reverse, key, idx0)
+            elif sz == 2:
+                self.__sort2(reverse, key, idx0)
+        else:
+            cur = self.connection.cursor()
+            mid = idx0 + math.ceil(sz / 2)
+            self._merge_sort(reverse, key, idx0, mid)
+            self._merge_sort(reverse, key, mid, idx1)
+            l = len(self)
+            self._driver_class.increase_indices_in_range(self.table_name, cur, idx0, mid, l)
+            p = idx0
+            i0 = idx0 + l
+            i1 = mid
+            k0 = key(self[i0])
+            k1 = key(self[i1])
+            if reverse:
+                while True:
+                    if k0 < k1:
+                        self._driver_class.set_index_by_index(self.table_name, cur, i1, p)
+                        p += 1
+                        i1 += 1
+                        if i1 == idx1:
+                            self._driver_class.increase_indices_in_range(self.table_name, cur, i0, mid + l, p - i0)
+                            break
+                        k1 = key(self[i1])
+                    else:
+                        self._driver_class.set_index_by_index(self.table_name, cur, i0, p)
+                        p += 1
+                        i0 += 1
+                        if i0 == mid + l:
+                            break
+                        k0 = key(self[i0])
+            else:
+                while True:
+                    if k0 > k1:
+                        self._driver_class.set_index_by_index(self.table_name, cur, i1, p)
+                        p += 1
+                        i1 += 1
+                        if i1 == idx1:
+                            self._driver_class.increase_indices_in_range(self.table_name, cur, i0, mid + l, p - i0)
+                            break
+                        k1 = key(self[i1])
+                    else:
+                        self._driver_class.set_index_by_index(self.table_name, cur, i0, p)
+                        p += 1
+                        i0 += 1
+                        if i0 == mid + l:
+                            break
+                        k0 = key(self[i0])
+
+    def __sort3(self, reverse: bool, key: Callable[[T], Any], idx: int) -> None:
+        a = key(self[idx])
+        b = key(self[idx + 1])
+        c = key(self[idx + 2])
+        cur = self.connection.cursor()
+        if not reverse:
+            if a > b:
+                self._driver_class.swap_indices(self.table_name, cur, idx, idx + 1)
+                a, b = b, a
+            if a > c:
+                self._driver_class.swap_indices(self.table_name, cur, idx, idx + 2)
+                a, c = c, a
+            if b > c:
+                self._driver_class.swap_indices(self.table_name, cur, idx + 1, idx + 2)
+        else:
+            if a < b:
+                self._driver_class.swap_indices(self.table_name, cur, idx, idx + 1)
+                a, b = b, a
+            if a < c:
+                self._driver_class.swap_indices(self.table_name, cur, idx, idx + 2)
+                a, c = c, a
+            if b < c:
+                self._driver_class.swap_indices(self.table_name, cur, idx + 1, idx + 2)
+
+    def __sort2(self, reverse: bool, key: Callable[[T], Any], idx: int) -> None:
+        a = key(self[idx])
+        b = key(self[idx + 1])
+        cur = self.connection.cursor()
+        if (reverse and a < b) or (not reverse and a > b):
+            self._driver_class.swap_indices(self.table_name, cur, idx, idx + 1)
+
     def reverse(self) -> None:
         cur = self.connection.cursor()
         self._driver_class.reverse_indices(self.table_name, cur)
